import logging
import os

basedir = os.path.dirname(__file__)
logging.basicConfig(
    level=logging.DEBUG, format="%(asctime)s - %(levelname)s - %(name)s - %(message)s"
)


class Config:
    RUM_SEED = "rum://seed?v=1&e=0&n=0&c=qOh_wTyuoKDoXmqGrP7Tfi1EAEFwTe81wZDbhEN4UKo&g=_NnW5VeXSgagNFD1VBE0tQ&k=A07OxsxC3apkq9mGTFeBGQK1aLDQ552hIjbIRZgjxaiN&s=nECW9-MqxEEmQ3sHu4_8F5boGkTsMBu8iYHf6IwweA5pUzQzT76KeQ6UT4fRLnspUnOehWxLmhB0fUvtHTqXdwA&t=F1bBbub7xqE&a=test_telegram_bot&y=group_timeline&u=http%3A%2F%2F158.69.15.98%3A8004%3Fjwt%3DeyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhbGxvd0dyb3VwIjoiZmNkOWQ2ZTUtNTc5Ny00YTA2LWEwMzQtNTBmNTU0MTEzNGI1IiwiZXhwIjoxODM5NDI0MTk1LCJuYW1lIjoiYWxsb3ctZmNkOWQ2ZTUtNTc5Ny00YTA2LWEwMzQtNTBmNTU0MTEzNGI1Iiwicm9sZSI6Im5vZGUifQ.fFyuVzMomMKEtJ_1RijpNhIaH5sa9TCLPkHCnpnROM8"
    ETH_PVTKEY = "0x5ee77ca3c261cddd6baaaa94be76f19d2a5997f2ca9921f68557e2266adeffaf"
    FEED_URL_BASE = "https://test.feed.base.one"
    FEED_TITLE = "My Feed"
    TG_USER_ID = 417326505
    TG_CHANNEL_NAME = "@hi_my_test_channel"
    TG_CHANNEL_URL = "https://t.me/hi_my_test_channel"
    TG_CHANNEL_ID = -1001869927577
    TG_BOT_TOKEN = "5847114777:AAEPNthtoyYxLUa4ywqWclMwD29vJbPcS4I"  # bot token
    TG_BOT_NAME = "@MyRumTestBot"
    # TG_GROUP_NAME = "@hi_my_test_channel_group"
    TG_GROUP_ID = -1001854966591
    DB_URL = f"sqlite:///{basedir}/test_db.sqlite"
    DB_ECHO = False
    RUM_DELAY_HOURS = -10
    RUM_POST_FOOTER = "#什么不值得买 "
    TG_REPLY_POSTURL = True
    BLACK_LIST_PUBKEYS = []
    BLACK_LIST_TGIDS = []


config = Config()



import json
import os
from dataclasses import dataclass


@dataclass
class Config:
    BLACK_LIST_PUBKEYS: list
    BLACK_LIST_TGIDS: list
    ADMIN_USERIDS: list
    RUM_SEED: str
    ETH_PVTKEY: str
    FEED_URL_BASE: str
    FEED_TITLE: str
    TG_USER_ID: int
    TG_CHANNEL_NAME: str
    TG_CHANNEL_URL: str
    TG_CHANNEL_ID: int
    TG_BOT_TOKEN: str
    TG_BOT_NAME: str
    TG_GROUP_NAME: str
    TG_GROUP_ID: int
    DB_URL: str
    DB_ECHO: bool
    RUM_DELAY_HOURS: int
    RUM_POST_FOOTER: str
    TG_REPLY_POSTURL: bool


def read_json(json_file: str):
    with open(json_file, "r", encoding="utf-8") as f:
        data = json.load(f)
    return data


def write_json(json_file: str, data: dict):
    with open(json_file, "w", encoding="utf-8") as f:
        json.dump(data, f, ensure_ascii=False, indent=4)
    return data


def get_config(json_file: str):
    if not os.path.exists(json_file):
        raise FileNotFoundError(f"Config file not found: {json_file}")
    data = read_json(json_file)
    config = Config(**data)
    return config



from sqlalchemy import Column, DateTime, Integer, String, UniqueConstraint
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.sql import func

Base = declarative_base()


class Relation(Base):
    """the map between trx and messages"""

    __tablename__ = "relations"

    id = Column(Integer, primary_key=True)
    group_id = Column(String, default=None)
    trx_id = Column(String, unique=True, index=True, default=None)
    trx_type = Column(String, default=None)  # rum
    rum_post_id = Column(String, default=None)  # rum
    rum_post_url = Column(String, default=None)
    chat_type = Column(String, default=None)
    chat_message_id = Column(Integer, index=True, default=None)
    channel_message_id = Column(Integer, index=True, default=None)
    user_id = Column(String, default=None)  # telegram user id
    pubkey = Column(String, default=None)  # rum group pubkey
    created_at = Column(DateTime, default=func.now())
    updated_at = Column(DateTime, onupdate=func.now())
    __table_args__ = (
        UniqueConstraint("group_id", "trx_id"),
        UniqueConstraint("chat_type", "chat_message_id"),
    )


class User(Base):
    __tablename__ = "users"

    id = Column(Integer, primary_key=True)
    user_id = Column(Integer, unique=True, index=True, default=None)
    username = Column(String, index=True, default=None)
    pvtkey = Column(String, unique=True, default=None)
    pubkey = Column(String, unique=True, default=None)
    address = Column(String, unique=True, default=None)
    created_at = Column(DateTime, default=func.now())
    updated_at = Column(DateTime, onupdate=func.now())
